package com.kddi.market.alml.service;

import com.kddi.market.alml.service.IAppAuthorizeServiceCallback;

interface IAppAuthorizeService {

	// ライセンス認証を行う
	// @param packageName: パッケージ名
	// @param callback: ライセンス認証結果コールバック
	// @param appName: アプリを識別する名前
	// @param cache: キャッシュを保持する秒数
	// @param seed: CPアプリ設定値（任意の値）
	void authorizeLicense(String packageName, IAppAuthorizeServiceCallback callback, long cache, String seed);
	
	// キャッシュを使用しないライセンス認証を行う
	// @param packageName: パッケージ名
	// @param callback: ライセンス認証結果コールバック
	// @param appName: アプリを識別する名前
	// @param seed: CPアプリ設定値（任意の値）
	void authorizeLicenseNoCache(String packageName, IAppAuthorizeServiceCallback callback, String seed);

	// キャッシュのクリアを行う
	void clearCache(String packageName);
	
	// 月額課金入会
	// @param packageName: パッケージ名
	// @param callback: 結果コールバック
	void joinMonthlyAccount(String packageName, IAppAuthorizeServiceCallback callback);
	
	// 月額課金退会
	// @param packageName: パッケージ名
	// @param callback: 結果コールバック
	void resignMonthlyAccount(String packageName, IAppAuthorizeServiceCallback callback);
	
	// 領収書発行
	// @param packageName: パッケージ名
	// @param callback: 結果コールバック
	// @param itemId: アイテムID
	// @param commodityId: 商品ID
	// @param summary:摘要
	// @param validityFlg:有効フラグ
	void issueReceipt(String packageName, IAppAuthorizeServiceCallback callback, String itemId, String commodityId, String summary,int validityFlg);

	// 領収書更新(古い仕様のため下のメソッドに置き換える)
	// @param packageName: パッケージ名
	// @param callback: 結果コールバック
	// @param itemId: アイテムID
	// @param payInfoId: 購入ID
	// @param commodityId: 商品ID
	// @param summary:摘要
	void updateReceipt(String packageName, IAppAuthorizeServiceCallback callabck, String itemId, String payInfoId, String commodityId, String summary);
	
	// 領収書更新
	// @param packageName: パッケージ名
	// @param callback: 結果コールバック
	// @param itemId: アイテムID
	// @param payInfoId: 購入ID
	// @param commodityId: 商品ID
	// @param summary:摘要
	// @param count: 更新回数
	void updateItemReceipt(String packageName, IAppAuthorizeServiceCallback callback, String itemId, String payInfoId, String commodityId, String summary, String count);
	
	// 領収書確認
	// @param packageName: パッケージ名
	// @param callback: 結果コールバック
	// @param itemId: アイテムID
	// @param payInfoId: 購入ID
	// @param commodityId: 商品ID
	// @param validityFlg:有効フラグ
	void confirmReceipt(String packageName, IAppAuthorizeServiceCallback callabck, String itemId, String payInfoId, String commodityId, int validity);
	
	// 領収書有効・無効設定
	// @param packageName: パッケージ名
	// @param callback: 結果コールバック
	// @param itemId: アイテムID
	// @param payInfoId: 購入ID
	// @param commodityId: 商品ID
	// @param validityFlg:有効フラグ
	void setItemValidity(String packageName, IAppAuthorizeServiceCallback callabck, String itemId, String payInfoId, String commodityId, int validity);
	
	// EZ番号取得
	// @param packageName: パッケージ名
	// @param callback: 結果コールバック
	void getEZNumber(String packageName, IAppAuthorizeServiceCallback callback);
	
	// au one トークン取得
	// @param activity: CPアプリのActivity
	// @param cpId: 各CPに割り振られるID
	// @param cpKey: 各CPに割り振られる鍵
	// @param callback: 結果コールバック
	// @param refresh: au one トークンをキャッシュクリアするかのフラグ
	void getAuOneToken(String cpId, String cpKey, IAppAuthorizeServiceCallback callback, boolean refresh);
	
}
